@@ -17,11 +17,11 @@ loon2ggplot.l_compound <- function(target, asAes = TRUE, selectedOnTop = TRUE,
   layout_matrix <- locations$layout_matrix
   plots <- lapply(target,
                   function(x) {
-                    loon.ggplot(x, asAes = asAes, selectedOnTop = selectedOnTop,
-                                showNearestColor = showNearestColor)
+                    loon2ggplot(x, asAes = asAes, selectedOnTop = selectedOnTop,
+                                showNearestColor = showNearestColor, ...)
                   })
 
-  positions <- layout_matrix2tlbr(layout_matrix, n = length(plots))
+  positions <- layout_matrix2positions(layout_matrix, n = length(plots))
 
   plots$design <- do.call(c,
                           lapply(seq(nrow(positions)),
